==> qtjambi-qt3dextras-debuginfo-macos-5.15.17.jar: sources/QtJambi3DExtras/Qt3DWindow_shell.h <==
#ifndef QT3DWINDOW_SHELL_H
#define QT3DWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DExtras/qt3dwindow.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qabstractaspect.h>
#include <Qt3DCore/qentity.h>
#include <Qt3DExtras/qforwardrenderer.h>
#include <Qt3DRender/qcamera.h>
#include <Qt3DRender/qframegraphnode.h>
#include <Qt3DRender/qrenderapi.h>
#include <Qt3DRender/qrendersettings.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtJambi/RegistryAPI>


class Qt3DWindow_shell : public Qt3DExtras::Qt3DWindow, public QtJambiShellInterface
{
public:
    Qt3DWindow_shell(QScreen* screen0 = nullptr, Qt3DRender::API arg__2 = Qt3DRender::API::OpenGL);
    ~Qt3DWindow_shell() override;

    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* e0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void showEvent(QShowEvent* e0) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Qt3DWindow_access : public Qt3DExtras::Qt3DWindow
{
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
};

#endif // QT3DWINDOW_SHELL_H

==> qtjambi-qt3dextras-debuginfo-macos-6.6.0.jar: sources/QtJambi3DExtras/Qt3DWindow_shell.h <==
#ifndef QT3DWINDOW_SHELL_H
#define QT3DWINDOW_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <Qt3DExtras/qt3dwindow.h>
#include <QtJambi/QtJambiAPI>
#include <Qt3DCore/qabstractaspect.h>
#include <Qt3DCore/qentity.h>
#include <Qt3DExtras/qforwardrenderer.h>
#include <Qt3DRender/qcamera.h>
#include <Qt3DRender/qframegraphnode.h>
#include <Qt3DRender/qrenderapi.h>
#include <Qt3DRender/qrendersettings.h>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtGui/qaccessible.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qicon.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qsurface.h>
#include <QtGui/qsurfaceformat.h>
#include <QtGui/qwindow.h>
#include <QtJambi/RegistryAPI>


class Qt3DWindow_shell : public Qt3DExtras::Qt3DWindow, public QtJambiShellInterface
{
public:
    Qt3DWindow_shell(QScreen* screen0 = nullptr, Qt3DRender::API arg__2 = Qt3DRender::API::RHI);
    ~Qt3DWindow_shell() override;

    QAccessibleInterface* accessibleRoot() const override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* arg__1) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* e0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void exposeEvent(QExposeEvent* arg__1) override;
    void focusInEvent(QFocusEvent* arg__1) override;
    QObject* focusObject() const override;
    void focusOutEvent(QFocusEvent* arg__1) override;
    QSurfaceFormat format() const override;
    void hideEvent(QHideEvent* arg__1) override;
    void keyPressEvent(QKeyEvent* arg__1) override;
    void keyReleaseEvent(QKeyEvent* arg__1) override;
    void mouseDoubleClickEvent(QMouseEvent* arg__1) override;
    void mouseMoveEvent(QMouseEvent* arg__1) override;
    void mousePressEvent(QMouseEvent* arg__1) override;
    void mouseReleaseEvent(QMouseEvent* arg__1) override;
    void moveEvent(QMoveEvent* arg__1) override;
    void paintEvent(QPaintEvent* arg__1) override;
    void resizeEvent(QResizeEvent* arg__1) override;
    void showEvent(QShowEvent* e0) override;
    QSize size() const override;
    QSurface::SurfaceType surfaceType() const override;
    void tabletEvent(QTabletEvent* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    void touchEvent(QTouchEvent* arg__1) override;
    void wheelEvent(QWheelEvent* arg__1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct Qt3DWindow_access : public Qt3DExtras::Qt3DWindow
{
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_resizeEvent_QResizeEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
    void __qt_showEvent_QShowEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
};

#endif // QT3DWINDOW_SHELL_H
